from django.contrib import admin

from .forms import BookAdminForm
from .models import Book


@admin.register(Book)
class BookAdmin(admin.ModelAdmin):
    form = BookAdminForm
    fieldsets = (
        (None, {
            'fields': ('title', 'author', 'product_code',
                       ('pages', 'isbn_code')),
        }),
    )



# Generated by Django 4.0.5 on 2022-06-14 11:48

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Book',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('author', models.CharField(max_length=200, verbose_name='Author')),
                ('product_code', models.CharField(max_length=20, verbose_name='Product code')),
                ('pages', models.IntegerField(blank=True, verbose_name='Pages')),
                ('isbn_code', models.CharField(blank=True, max_length=20, verbose_name='ISBN code')),
            ],
        ),
    ]



from django.db import models


class Book(models.Model):
    title = models.CharField(
        'Title',
        max_length=200
    )

    author = models.CharField(
        'Author',
        max_length=200
    )

    product_code = models.CharField(
        'Product code',
        max_length=20
    )

    pages = models.IntegerField(
        'Pages',
        blank=True
    )

    isbn_code = models.CharField(
        'ISBN code',
        max_length=20,
        blank=True
    )



from django import forms
from prefixed_textinput import PrefixedTextInput


class BookAdminForm(forms.ModelForm):
    class Meta:
        widgets = {
            'product_code':
                PrefixedTextInput(prefix='SKU'),
            'isbn_code':
                PrefixedTextInput(prefix='ISBN'),
        }
        fields = '__all__'



#!/usr/bin/env python

''' To make a new release:
    1. Bump version number in setup.py
    2. Update CHANGELOG
    3. $ git commit ...
    4. $ git tag -a x.x.x  # see `git tags` for latest
    5. $ git push origin main
    6. $ git push --tags
    7. $ python setup.py register sdist
    8. $ twine upload dist/*
'''

from setuptools import setup, find_packages  # noqa: E402


VERSION = '.'.join(('0', '1', '1'))

DESCRIPTION = '''An extension of the default TextInput widget that displays a
              read-only string prefix'''

CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3.6',
    'Topic :: Software Development :: Libraries :: Python Modules',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    'Framework :: Django',
    'Framework :: Django :: 3.2',
    'Framework :: Django :: 4.0',
]

setup(
    name='django-prefixed-textinput',
    version=VERSION,
    description=DESCRIPTION,
    long_description=open('README.md', 'r', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author='James Tiplady',
    maintainer='James Tiplady',
    license='MIT',
    keywords=['django'],
    platforms=['OS Independent'],
    url='http://github.com/BigglesZX/django-prefixed-textinput',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    python_requires='>=3.6,<4',
    install_requires=['Django>=3.2'],
    extras_require={
        'dev': [
            'Django>=3.2',
            'flake8>=3.7.7',
            'setuptools>=41.0.0',
            'twine>=1.13.0',
            'wheel>=0.33.1',
        ]
    },
    classifiers=CLASSIFIERS
)



from django.forms.widgets import TextInput


class PrefixedTextInput(TextInput):
    template_name = 'widget.html'

    class Media:
        css = {
            'all': ('css/widget.css',),
        }

    def __init__(self, attrs=None, prefix=''):
        self.prefix = prefix
        super().__init__(attrs)

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)
        context["widget"]["prefix"] = self.prefix
        return context
